aboutsummaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
authorDouglas Gilbert <dgilbert@interlog.com>2021-05-15 21:17:40 +0000
committerDouglas Gilbert <dgilbert@interlog.com>2021-05-15 21:17:40 +0000
commit46fc8659ec9bfc87e58008a5341393a86ca40c52 (patch)
treeb7b8af0a5107f2c53a9215c880d8e8e0863b2ac9 /include
parenta5226c6f336ee819b21e5b27e971fa560502c844 (diff)
downloadsg3_utils-46fc8659ec9bfc87e58008a5341393a86ca40c52.tar.gz
sg_lib: add sg_scsi_status_is_bad(); testing/ work
git-svn-id: https://svn.bingwo.ca/repos/sg3_utils/trunk@901 6180dd3e-e324-4e3e-922d-17de1ae2f315
Diffstat (limited to 'include')
-rw-r--r--include/sg_lib.h6
1 files changed, 4 insertions, 2 deletions
diff --git a/include/sg_lib.h b/include/sg_lib.h
index ae228bcc..108ab873 100644
--- a/include/sg_lib.h
+++ b/include/sg_lib.h
@@ -189,9 +189,11 @@ struct sg_scsi_sense_hdr {
uint8_t additional_length; /* zero for fixed format sense data */
};
/* Returns true when status is SAM_STAT_GOOD or SAM_STAT_CONDITION_MET,
* returns false otherwise. Ignores bit 0. */
bool sg_scsi_status_is_good(int sstatus);
+bool sg_scsi_status_is_bad(int sstatus);
/* Maps the salient data from a sense buffer which is in either fixed or
* descriptor format into a structure mimicking a descriptor format
@@ -189,9 +189,11 @@ struct sg_scsi_sense_hdr {
uint8_t additional_length; /* zero for fixed format sense data */
};
-/* Returns true when status is SAM_STAT_GOOD or SAM_STAT_CONDITION_MET,
- * returns false otherwise. Ignores bit 0. */
+/* The '_is_good()' returns true when status is SAM_STAT_GOOD or
+ * SAM_STAT_CONDITION_MET, returns false otherwise. Ignores bit 0. The
+ * '_is_bad() variant is the logical inverse. */
bool sg_scsi_status_is_good(int sstatus);